package com.magick.trade_service.client;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.ObjectMessage;
import javax.jms.Queue;
import javax.jms.Session;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import com.magick.models.TradeOrder;

/**
 * 
 * @author nik
 * 
 *         Client class for sending order to JMS queue via HornetQ
 */
public class HornetQClient {
	private final static String ORDER_QUEUE = "orderQueue";
	private final static String CONNECTION_FACTORY = "java:/ConnectionFactory";
	private MessageProducer producer;
	private Session session;

	public HornetQClient() {
	}

	public void initialize() {
		try {
			InitialContext ic = new InitialContext();
			ConnectionFactory cf = (ConnectionFactory) ic
					.lookup(CONNECTION_FACTORY);

			Connection connection = null;
			connection = cf.createConnection();
			connection.start();
			session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
			Queue queue = (Queue) ic.lookup("/queue/" + ORDER_QUEUE);
			producer = session.createProducer(queue);
		} catch (JMSException e) {
			e.printStackTrace();
		} catch (NamingException e1) {
			e1.printStackTrace();
		}
	}

	public void sendOrder(TradeOrder order) {
		try {
			ObjectMessage message = session.createObjectMessage(order);
			producer.send(message);
		} catch (JMSException e) {
			e.printStackTrace();
		}
	}
}
