package com.magick.trade_service.service;

import org.switchyard.component.bean.Service;


import com.magick.models.TradeOrder;
import com.magick.trade_service.client.HornetQClient;
import com.magick.trade_service.model.parameter.OrderCloseByParams;
import com.magick.trade_service.model.parameter.OrderCloseParams;
import com.magick.trade_service.model.parameter.OrderDeleteParams;
import com.magick.trade_service.model.parameter.OrderModifyParams;
import com.magick.trade_service.model.parameter.OrderSelectParams;
import com.magick.trade_service.model.parameter.OrderSendParams;

/**
 * 
 * @author nik
 * 
 *         Implementation of OrderService interface, which generates TradeOrder
 *         object and send it to JMS queue, when any method is invoked
 */
@Service(OrderService.class)
public class OrderServiceBean implements OrderService {
	private HornetQClient hornetQClient = new HornetQClient();

	public OrderServiceBean() {
		hornetQClient.initialize();
	}

	@Override
	public void orderClose(OrderCloseParams params) {
		TradeOrder order = new TradeOrder();
		order.setPrice(params.getPrice());
		order.setOrderLots(params.getLots());
		order.setSlippage(params.getSlippage());
		order.setOrderTicket(params.getTicket());
		hornetQClient.sendOrder(order);
	}

	@Override
	public void orderCloseBy(OrderCloseByParams params) {
		TradeOrder order = new TradeOrder();
		order.setOrderTicket(params.getTicket());
		hornetQClient.sendOrder(order);
	}

	@Override
	public void orderDelete(OrderDeleteParams params) {
		TradeOrder order = new TradeOrder();
		order.setOrderTicket(params.getTicket());
		// TODO: complete binding fields
		hornetQClient.sendOrder(order);
	}

	@Override
	public void orderModify(OrderModifyParams params) {
		TradeOrder order = new TradeOrder();
		order.setExpiration(params.getExpiration());
		order.setOrderTicket(params.getTicket());
		order.setTakeprofit(params.getTakeprofit());
		order.setStoploss(params.getStoploss());
		order.setPrice(params.getPrice());
		hornetQClient.sendOrder(order);
	}

	@Override
	public void orderSelect(OrderSelectParams params) {
		TradeOrder order = new TradeOrder();
		// TODO: configure order
		order.setOrderTicket(params.getIndex());
		hornetQClient.sendOrder(order);
	}

	@Override
	public TradeOrder orderSend(OrderSendParams params) {
		TradeOrder order = new TradeOrder();
		order.setOperation(params.getOperationType());
		order.setComment(params.getComment());
		order.setMagic(params.getMagic());
		order.setSlippage(params.getSlippage());
		order.setStoploss(params.getStoploss());
		order.setTakeprofit(params.getTakeprofit());
		order.setVolume(params.getVolume());
		order.setSymbol(params.getSymbol());
		order.setExpiration(params.getExpiration());
		order.setPrice(params.getPrice());
		hornetQClient.sendOrder(order);
		return order;
	}
	/*
	@Override
	public Double getOrderClosePrice() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Date getOrderCloseTime() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public String getOrderComment() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Double getOrderCommission() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Date getOrderExpiration() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Double getOrderLots() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Integer getOrderMagicNumber() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Double getOrderOpenPrice() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Date getOrderOpenTime() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public void orderPrint() {
		// TODO Auto-generated method stub

	}

	@Override
	public Double getOrderProfit() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Integer getOrdersHistoryTotal() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Double getOrderStopLoss() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Integer getOrdersTotal() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Double getOrderSwap() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public String getOrderSymbol() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Double getOrderTakeProfit() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Integer getOrderTicket() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Integer getOrderType() {
		// TODO Auto-generated method stub
		return null;
	}
	*/
}
