package com.magick.trade_service.service.transformer;

import java.io.StringReader;
import java.text.ParseException;
import java.text.SimpleDateFormat;

import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMResult;
import javax.xml.transform.stream.StreamSource;

import org.switchyard.annotations.Transformer;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import com.magick.trade_service.model.parameter.OrderCloseByParams;
import com.magick.trade_service.model.parameter.OrderCloseParams;
import com.magick.trade_service.model.parameter.OrderDeleteParams;
import com.magick.trade_service.model.parameter.OrderModifyParams;
import com.magick.trade_service.model.parameter.OrderSelectParams;
import com.magick.trade_service.model.parameter.OrderSendParams;

public class OrderServiceTransformer {
	private static final String DATE_FORMAT = "yyyy-MM-dd'T'HH:mm:ss";

	@Transformer(from = "{urn:com.example.switchyard:order-service:0.0.1-SNAPSHOT}orderClose")
	public OrderCloseParams orderCloseTransform(Element from) {
		OrderCloseParams params = new OrderCloseParams();
		params.setColor(getElementValue(from, "color"));
		params.setLots(Double.parseDouble(getElementValue(from, "lots")));
		params.setPrice(Double.parseDouble(getElementValue(from, "price")));
		params.setSlippage(Integer.parseInt(getElementValue(from, "slippage")));
		params.setTicket(Integer.parseInt(getElementValue(from, "ticket")));
		return params;
	}

	@Transformer(from = "{urn:com.example.switchyard:order-service:0.0.1-SNAPSHOT}orderCloseBy")
	public OrderCloseByParams OrderCloseByTransform(Element from) {
		OrderCloseByParams params = new OrderCloseByParams();
		params.setColor(getElementValue(from, "color"));
		params.setOpposite(Integer.parseInt(getElementValue(from, "opposite")));
		params.setTicket(Integer.parseInt(getElementValue(from, "ticket")));
		return params;
	}

	@Transformer(from = "{urn:com.example.switchyard:order-service:0.0.1-SNAPSHOT}orderDelete")
	public OrderDeleteParams OrderDeleteTransform(Element from) {
		OrderDeleteParams params = new OrderDeleteParams();
		params.setColor(getElementValue(from, "color"));
		params.setTicket(Integer.parseInt(getElementValue(from, "ticket")));
		return params;
	}

	@Transformer(from = "{urn:com.example.switchyard:order-service:0.0.1-SNAPSHOT}orderModify")
	public OrderModifyParams OrderModifyTransform(Element from)
			throws ParseException {
		OrderModifyParams params = new OrderModifyParams();
		params.setColor(getElementValue(from, "color"));
		params.setTicket(Integer.parseInt(getElementValue(from, "ticket")));
		params.setPrice(Double.parseDouble(getElementValue(from, "price")));
		params.setStoploss(Double
				.parseDouble(getElementValue(from, "stoploss")));
		params.setTakeprofit(Double.parseDouble(getElementValue(from,
				"takeprofit")));
		String date = getElementValue(from, "expiration");
		SimpleDateFormat dateFormat = new SimpleDateFormat(DATE_FORMAT);
		params.setExpiration(dateFormat.parse(date));
		return params;
	}

	@Transformer(from = "{urn:com.example.switchyard:order-service:0.0.1-SNAPSHOT}orderSelect")
	public OrderSelectParams OrderSelectTransform(Element from) {
		OrderSelectParams params = new OrderSelectParams();
		params.setIndex(Integer.parseInt(getElementValue(from, "index")));
		params.setPool(Integer.parseInt(getElementValue(from, "pool")));
		params.setSelect(Integer.parseInt(getElementValue(from, "select")));
		return params;
	}

	@Transformer(from = "{urn:com.example.switchyard:order-service:0.0.1-SNAPSHOT}orderSend")
	public OrderSendParams OrderSendTransform(Element from) throws ParseException {
		OrderSendParams params = new OrderSendParams();
		params.setColor(getElementValue(from, "color"));
		params.setComment(getElementValue(from, "comment"));
		params.setMagic(Integer.parseInt(getElementValue(from, "magic")));
		params.setOperationType(getElementValue(from, "operationType"));
		params.setPrice(Double.parseDouble(getElementValue(from, "price")));
		params.setSlippage(Integer.parseInt(getElementValue(from, "slippage")));
		params.setStoploss(Double
				.parseDouble(getElementValue(from, "stoploss")));
		params.setTakeprofit(Double.parseDouble(getElementValue(from,
				"takeprofit")));
		params.setSymbol(getElementValue(from, "symbol"));
		params.setVolume(Double.parseDouble(getElementValue(from, "volume")));
		String date = getElementValue(from, "expiration");
		SimpleDateFormat dateFormat = new SimpleDateFormat(DATE_FORMAT);
		params.setExpiration(dateFormat.parse(date));
		return params;
	}

	/**
	 * Returns the text value of a child node of parent.
	 */
	private String getElementValue(Element parent, String elementName) {
		String value = null;
		NodeList nodes = parent.getElementsByTagName(elementName);
		if (nodes.getLength() > 0) {
			value = nodes.item(0).getChildNodes().item(0).getNodeValue();
		}
		return value;
	}

	private Element toElement(String xml) {
		DOMResult dom = new DOMResult();
		try {
			TransformerFactory.newInstance().newTransformer()
					.transform(new StreamSource(new StringReader(xml)), dom);
		} catch (Exception ex) {
			ex.printStackTrace();
		}

		return ((Document) dom.getNode()).getDocumentElement();
	}
}
